==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-drools/kie-drl/kie-drl-compilation-common/src/main/java/org/kie/drl/engine/compilation/model/DrlCompilationContext.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.kie.drl.engine.compilation.model;

import org.kie.efesto.compilationmanager.api.model.EfestoCompilationContext;
import org.kie.efesto.compilationmanager.core.model.EfestoCompilationContextImpl;
import org.kie.efesto.compilationmanager.core.model.EfestoCompilationContextUtils;
import org.kie.internal.builder.KnowledgeBuilderConfiguration;
import org.kie.memorycompiler.KieMemoryCompiler;

public interface DrlCompilationContext extends EfestoCompilationContext {

    static DrlCompilationContext buildWithParentClassLoader(ClassLoader parentClassLoader) {
        return new DrlCompilationContextImpl(new KieMemoryCompiler.MemoryCompilerClassLoader(parentClassLoader));
    }

    static DrlCompilationContext buildWithMemoryCompilerClassLoader(KieMemoryCompiler.MemoryCompilerClassLoader memoryCompilerClassLoader) {
        return new DrlCompilationContextImpl(memoryCompilerClassLoader);
    }

    static DrlCompilationContext buildWithEfestoCompilationContext(EfestoCompilationContextImpl context) {
        return (DrlCompilationContext) EfestoCompilationContextUtils.buildFromContext(context, DrlCompilationContextImpl.class);
    }

    KnowledgeBuilderConfiguration newKnowledgeBuilderConfiguration();
}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-drools/kie-drl/kie-drl-compilation-common/src/main/java/org/kie/drl/engine/compilation/model/DrlCompilationContext.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.kie.drl.engine.compilation.model;

import org.kie.efesto.common.api.model.EfestoCompilationContext;
import org.kie.efesto.compilationmanager.core.model.EfestoCompilationContextImpl;
import org.kie.efesto.compilationmanager.core.model.EfestoCompilationContextUtils;
import org.kie.internal.builder.KnowledgeBuilderConfiguration;
import org.kie.memorycompiler.KieMemoryCompiler;

public interface DrlCompilationContext extends EfestoCompilationContext {

    static DrlCompilationContext buildWithParentClassLoader(ClassLoader parentClassLoader) {
        return new DrlCompilationContextImpl(new KieMemoryCompiler.MemoryCompilerClassLoader(parentClassLoader));
    }

    static DrlCompilationContext buildWithMemoryCompilerClassLoader(KieMemoryCompiler.MemoryCompilerClassLoader memoryCompilerClassLoader) {
        return new DrlCompilationContextImpl(memoryCompilerClassLoader);
    }

    static DrlCompilationContext buildWithEfestoCompilationContext(EfestoCompilationContextImpl context) {
        return (DrlCompilationContext) EfestoCompilationContextUtils.buildFromContext(context, DrlCompilationContextImpl.class);
    }

    KnowledgeBuilderConfiguration newKnowledgeBuilderConfiguration();
}
